import javax.swing.JComponent;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.image.BufferedImage;

/**
 * @author Erik Schlyter
 * @version 1.0
 *
 *	MyComponent
 *	This is an example on how you can override the method paintComponent
 *  to get more control over the graphics. Since you'll recieve a object
 *  of the class Graphics in the method call, you can paint anything you want.
 * 
 *  The component uses a buffered image (class BufferedImage) as background,
 *  and every graphics operation is done to this image. Whenever the parent
 *  component (i.e. a JFrame, a JPanel or whatever swing object you've put
 *  it in) wants to repaint this component, that image is painted.  
 */

public class MyComponent extends JComponent {

	private int fixedWidth;
	private int fixedHeight;
	private BufferedImage image;

	/**
	 * Constructs a new MyComponent with a specified witdth and height.
	 * 
	 * @param width The desired width of the component
	 * @param height The desired height of the component
	 */
	public MyComponent (int width, int height) {
		super();
		fixedWidth = width;
		fixedHeight = height;
		image = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);

		// Make the component white
		Graphics g = image.getGraphics();
		g.setColor(Color.white);
		g.fillRect(0,0,width, height);
	}


	/**
 	* Bypass JComponents method to paint this component. Draw our BufferedImage
 	* instead. 
 	*/
	public synchronized void paintComponent(Graphics g) {
		g.drawImage(image, 0,0, null);
	}

	/**
	 * A simple method to draw a line on our buffered image.
	 * @param x1
	 * @param y1
	 * @param x2
	 * @param y2
	 * @param c
	 */
	public void drawLine (int x1, int y1, int x2, int y2, Color c) {
			Graphics g = image.getGraphics();
			g.setColor(c);
			g.drawLine(x1, y1, x2, y2);	
	}

	/**
	 * A simple method to draw a string of text on our buffered image.
	 * @param s
	 * @param x
	 * @param y
	 * @param c
	 */
	public void drawString (String s, int x, int y, Color c) {
		Graphics g = image.getGraphics();
		g.setColor(c);
		g.drawString(s, x, y);	
	}


	public void drawImage(BufferedImage bi) {
		Graphics g = image.getGraphics();
		g.drawImage(bi, 20, 20, null);
		
	}
}
