import java.awt.Color;
import java.awt.Container;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;
import javax.swing.BoxLayout;
import javax.swing.JFrame;

/**
 * @author Erik Schlyter
 * @version 1.0
 *
 *	MyExample
 *	This is just an example on how to use my own MyComponent
 *	to get more control over graphics in Java. This frame
 *  uses a Thread to try and keep up with a given number
 *	of frames per second.
 */

public class MyExample extends JFrame implements Runnable {

	private final int FRAMES_PER_SECOND =24;
	private Thread myThread;
	private MyComponent gfx;

	/**
	 * Constructor
	 *
	 * Create a MyComponent and draw some funny things on it.
	 * @throws IOException 
	 **/
	public MyExample() throws IOException {
		super();

		gfx = new MyComponent(500, 400);
		gfx.setVisible(true);

		Container panel = this.getContentPane();
		panel.setLayout(new BoxLayout(panel, BoxLayout.PAGE_AXIS));
		panel.add(gfx);
		File f = new File("not_valid.gif");
		BufferedImage bi = ImageIO.read(f);

		gfx.drawLine(30, 30, 300, 200, Color.red);
		gfx.drawLine(50, 40, 280, 180, Color.green);
		gfx.drawLine(70, 50, 260, 160, Color.blue);
		gfx.drawImage(bi);
		gfx.drawString(
			"If you override paintComponent, you can paint what "
				+ "you want, where you want!",
			20,
			150,
			Color.blue);



		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		this.setSize(640, 480);
		this.setTitle("A graphics example using overriden Java methods");
		this.setVisible(true);

		myThread = new Thread(this);
		myThread.start();

	}
/* (non-Javadoc)
 * @see java.lang.Runnable#run()
 */
	public void run() {

		// variebles used to paint a animated line
		
		double angle = 0;
		int x = 40;
		int y = 250;
		while (myThread != null) {

			synchronized (gfx) {
				gfx.drawLine(
					x,
					y,
					x + (int) (Math.cos(angle) * 30),
					y + (int) (Math.sin(angle) * 30),
					Color.white);

				angle += Math.PI / 40;
				if (angle > (2 * Math.PI))
					angle -= (2 * Math.PI);

				gfx.drawLine(
					x,
					y,
					x + (int) (Math.cos(angle) * 30),
					y + (int) (Math.sin(angle) * 30),
					Color.red);
			}
			gfx.repaint(); // tell MyComponent to repaint itself

			try {
				// Try to keep a given number of frames per second.
				Thread.sleep(1000 / FRAMES_PER_SECOND);
			} catch (InterruptedException e) {
				System.err.println("Error in thread, exiting.");
				return;
			}
		}
	}

/**
 * the Main method
 * @param args
 */
	public static void main(String[] args) {
		try {
			MyExample e = new MyExample();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

	}

}
